@@ -18,9 +18,10 @@
 package com.mongodb.crypt.capi;
 
 import org.bson.BsonDocument;
-
+import java.util.List;
 import java.util.Map;
 
+import static java.util.Collections.emptyList;
 import static org.bson.assertions.Assertions.isTrue;
 
 /**
@@ -31,9 +32,13 @@ public class MongoCryptOptions {
     private final MongoAwsKmsProviderOptions awsKmsProviderOptions;
     private final MongoLocalKmsProviderOptions localKmsProviderOptions;
     private final BsonDocument kmsProviderOptions;
-
     private final Map<String, BsonDocument> localSchemaMap;
     private final boolean needsKmsCredentialsStateEnabled;
+    private final Map<String, BsonDocument> encryptedFieldsMap;
+    private final BsonDocument extraOptions;
+    private final boolean bypassQueryAnalysis;
+    private final List<String> searchPaths;
+
 
     /**
      * Construct a builder for the options
@@ -91,6 +96,44 @@ public class MongoCryptOptions {
         return needsKmsCredentialsStateEnabled;
     }
 
+    /**
+     * Gets the encrypted fields map.
+     *
+     * @since 1.5
+     * @return the encrypted fields map
+     */
+    public Map<String, BsonDocument> getEncryptedFieldsMap() {
+        return encryptedFieldsMap;
+    }
+
+    /**
+     * Gets whether automatic analysis of outgoing commands should be disabled.
+     *
+     * @since  1.5
+     * @return true if bypassing query analysis
+     */
+    public boolean isBypassQueryAnalysis() {
+        return bypassQueryAnalysis;
+    }
+
+    /**
+     * The extraOptions that relate to the mongocryptd process or shared library.
+     * @return the extra options
+     * @since 1.5
+     */
+    public BsonDocument getExtraOptions() {
+        return extraOptions;
+    }
+
+    /**
+     * Gets the search paths
+     * @return this
+     * @since 1.5
+     */
+    public List<String> getSearchPaths() {
+        return searchPaths;
+    }
+
     /**
      * The builder for the options
      */
@@ -100,6 +143,10 @@ public class MongoCryptOptions {
         private BsonDocument kmsProviderOptions = null;
         private Map<String, BsonDocument> localSchemaMap = null;
         private boolean needsKmsCredentialsStateEnabled;
+        private Map<String, BsonDocument> encryptedFieldsMap  = null;
+        private boolean bypassQueryAnalysis;
+        private BsonDocument extraOptions = new BsonDocument();
+        private List<String> searchPaths = emptyList();
 
         private Builder() {
         }
@@ -161,6 +208,55 @@ public class MongoCryptOptions {
             return this;
         }
 
+        /**
+         * Sets the encrypted fields map.
+         *
+         * @param encryptedFieldsMap the encrypted fields map
+         * @since 1.5
+         * @return this
+         */
+        public Builder encryptedFieldsMap(final Map<String, BsonDocument> encryptedFieldsMap) {
+            this.encryptedFieldsMap = encryptedFieldsMap;
+            return this;
+        }
+
+        /**
+         * Sets whether automatic analysis of outgoing commands should be disabled.
+         *
+         * <p>Set bypassQueryAnalysis to true to use explicit encryption on indexed fields
+         * without the MongoDB Enterprise Advanced licensed crypt shared library.</p>
+         *
+         * @param bypassQueryAnalysis whether the analysis of outgoing commands should be disabled.
+         * @since  1.5
+         * @return  this
+         */
+        public Builder bypassQueryAnalysis(final boolean bypassQueryAnalysis) {
+            this.bypassQueryAnalysis = bypassQueryAnalysis;
+            return this;
+        }
+
+        /**
+         * The extraOptions that relate to the mongocryptd process or shared library.
+         * @param extraOptions the extraOptions
+         * @return this
+         * @since 1.5
+         */
+        public Builder extraOptions(final BsonDocument extraOptions) {
+            this.extraOptions = extraOptions;
+            return this;
+        }
+
+        /**
+         * Sets search paths
+         * @param searchPaths sets search path
+         * @return this
+         * @since 1.5
+         */
+        public Builder searchPaths(final List<String> searchPaths) {
+            this.searchPaths = searchPaths;
+            return this;
+        }
+
         /**
          * Build the options.
          *
@@ -180,5 +276,9 @@ public class MongoCryptOptions {
         this.kmsProviderOptions = builder.kmsProviderOptions;
         this.localSchemaMap = builder.localSchemaMap;
         this.needsKmsCredentialsStateEnabled = builder.needsKmsCredentialsStateEnabled;
+        this.encryptedFieldsMap = builder.encryptedFieldsMap;
+        this.bypassQueryAnalysis = builder.bypassQueryAnalysis;
+        this.extraOptions = builder.extraOptions;
+        this.searchPaths = builder.searchPaths;
     }
 }
