@@ -14,6 +14,7 @@
  * limitations under the License.
  */
 
+#include "mongocrypt-kms-ctx-private.h"
 #include "test-mongocrypt.h"
 
 #define TEST_REWRAP_MASTER_KEY_ID_OLD                                                                                  \
@@ -496,6 +497,83 @@ static void _test_rewrap_many_datakey_need_kms_decrypt(_mongocrypt_tester_t *tes
     mongocrypt_destroy(crypt);
 }
 
+static void _test_rewrap_many_datakey_need_kms_retry(_mongocrypt_tester_t *tester) {
+    mongocrypt_binary_t *const filter = TEST_BSON("{'keyAltName': {'$in': ['keyDocumentA', 'keyDocumentB']}}");
+    mongocrypt_t *crypt = _mongocrypt_tester_mongocrypt(TESTER_MONGOCRYPT_DEFAULT);
+    mongocrypt_ctx_t *ctx = NULL;
+    mongocrypt_kms_ctx_t *kms = NULL;
+
+    /* Ensure KMS decrypt requests retry for HTTP errors */
+    ctx = mongocrypt_ctx_new(crypt);
+    ASSERT_OK(mongocrypt_ctx_rewrap_many_datakey_init(ctx, filter), ctx);
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_NEED_MONGO_KEYS);
+    ASSERT_OK(mongocrypt_ctx_mongo_feed(ctx, TEST_FILE("./test/data/rmd/key-document-a.json")), ctx);
+    ASSERT_OK(mongocrypt_ctx_mongo_done(ctx), ctx);
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_NEED_KMS); // To decrypt.
+    ASSERT((kms = mongocrypt_ctx_next_kms_ctx(ctx)));
+    for (int i = 0; i < kms_max_attempts; i++) {
+        ASSERT_OK(mongocrypt_kms_ctx_feed(kms, TEST_FILE("./test/data/rmd/kms-decrypt-reply-429.txt")), kms);
+        ASSERT(mongocrypt_kms_ctx_bytes_needed(kms) == 0);
+        ASSERT((kms = mongocrypt_ctx_next_kms_ctx(ctx)));
+        ASSERT(mongocrypt_kms_ctx_usleep(kms) > 0);
+    }
+    ASSERT_OK(mongocrypt_kms_ctx_feed(kms, TEST_FILE("./test/data/rmd/kms-decrypt-reply-a.txt")), kms);
+    ASSERT(mongocrypt_kms_ctx_bytes_needed(kms) == 0);
+    ASSERT_OK(mongocrypt_ctx_kms_done(ctx), ctx);
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_NEED_KMS); // To encrypt.
+    mongocrypt_ctx_destroy(ctx);
+
+    /* Clear key cache. */
+    mongocrypt_destroy(crypt);
+    crypt = _mongocrypt_tester_mongocrypt(TESTER_MONGOCRYPT_DEFAULT);
+
+    /* Ensure KMS decrypt requests retried for HTTP errors fail after max attempts */
+    ctx = mongocrypt_ctx_new(crypt);
+    ASSERT_OK(mongocrypt_ctx_rewrap_many_datakey_init(ctx, filter), ctx);
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_NEED_MONGO_KEYS);
+    ASSERT_OK(mongocrypt_ctx_mongo_feed(ctx, TEST_FILE("./test/data/rmd/key-document-a.json")), ctx);
+    ASSERT_OK(mongocrypt_ctx_mongo_done(ctx), ctx);
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_NEED_KMS);
+    ASSERT((kms = mongocrypt_ctx_next_kms_ctx(ctx)));
+    for (int i = 0; i <= kms_max_attempts; i++) {
+        if (i == kms_max_attempts) {
+            ASSERT_FAILS(mongocrypt_kms_ctx_feed(kms, TEST_FILE("./test/data/rmd/kms-decrypt-reply-429.txt")),
+                         kms,
+                         "retries");
+            break;
+        }
+        ASSERT_OK(mongocrypt_kms_ctx_feed(kms, TEST_FILE("./test/data/rmd/kms-decrypt-reply-429.txt")), kms);
+        ASSERT(mongocrypt_kms_ctx_bytes_needed(kms) == 0);
+        ASSERT((kms = mongocrypt_ctx_next_kms_ctx(ctx)));
+        ASSERT(mongocrypt_kms_ctx_usleep(kms) > 0);
+    }
+    ASSERT_FAILS(mongocrypt_ctx_kms_done(ctx), ctx, "retries");
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_ERROR);
+    mongocrypt_ctx_destroy(ctx);
+
+    /* Clear key cache. */
+    mongocrypt_destroy(crypt);
+    crypt = _mongocrypt_tester_mongocrypt(TESTER_MONGOCRYPT_DEFAULT);
+
+    /* Ensure KMS decrypt requests retry for network errors */
+    ctx = mongocrypt_ctx_new(crypt);
+    ASSERT_OK(mongocrypt_ctx_rewrap_many_datakey_init(ctx, filter), ctx);
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_NEED_MONGO_KEYS);
+    ASSERT_OK(mongocrypt_ctx_mongo_feed(ctx, TEST_FILE("./test/data/rmd/key-document-a.json")), ctx);
+    ASSERT_OK(mongocrypt_ctx_mongo_done(ctx), ctx);
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_NEED_KMS);
+    ASSERT((kms = mongocrypt_ctx_next_kms_ctx(ctx)));
+    ASSERT(mongocrypt_kms_ctx_fail(kms)); //  Simulate driver-side network failure
+    ASSERT((kms = mongocrypt_ctx_next_kms_ctx(ctx)));
+    ASSERT(mongocrypt_kms_ctx_usleep(kms) > 0);
+    ASSERT_OK(mongocrypt_kms_ctx_feed(kms, TEST_FILE("./test/data/rmd/kms-decrypt-reply-a.txt")), kms);
+    ASSERT(mongocrypt_kms_ctx_bytes_needed(kms) == 0);
+    ASSERT_OK(mongocrypt_ctx_kms_done(ctx), ctx);
+    ASSERT_STATE_EQUAL(mongocrypt_ctx_state(ctx), MONGOCRYPT_CTX_NEED_KMS); // To encrypt.
+    mongocrypt_ctx_destroy(ctx);
+    mongocrypt_destroy(crypt);
+}
+
 static void _test_rewrap_many_datakey_need_kms_encrypt(_mongocrypt_tester_t *tester) {
     mongocrypt_binary_t *const filter = TEST_BSON("{'keyAltName': {'$in': ['keyDocumentA', 'keyDocumentB']}}");
 
@@ -841,6 +919,7 @@ void _mongocrypt_tester_install_ctx_rewrap_many_datakey(_mongocrypt_tester_t *te
     INSTALL_TEST(_test_rewrap_many_datakey_init);
     INSTALL_TEST(_test_rewrap_many_datakey_need_mongo_keys);
     INSTALL_TEST(_test_rewrap_many_datakey_need_kms_decrypt);
+    INSTALL_TEST(_test_rewrap_many_datakey_need_kms_retry);
     INSTALL_TEST(_test_rewrap_many_datakey_need_kms_encrypt);
     INSTALL_TEST(_test_rewrap_many_datakey_finalize);
     INSTALL_TEST(_test_rewrap_many_datakey_kms_credentials);
